@@ -2,7 +2,7 @@
 
 -- |
 -- Module      : Language.Haskell.TH.Compat.Data
--- Copyright   : 2016 Kei Hibino
+-- Copyright   : 2016-2017 Kei Hibino
 -- License     : BSD3
 --
 -- Maintainer  : ex8k.hibino@gmail.com
@@ -19,8 +19,10 @@ module Language.Haskell.TH.Compat.Data (
   unDataD, unNewtypeD, unDataInstD, unNewtypeInstD, unInstanceD,
   ) where
 
-#if MIN_VERSION_template_haskell(2,11,0)
+#if MIN_VERSION_template_haskell(2,12,0)
 import Language.Haskell.TH.Compat.Data.Current
+#elif MIN_VERSION_template_haskell(2,11,0)
+import Language.Haskell.TH.Compat.Data.V211
 #else
 import Language.Haskell.TH.Compat.Data.V210
 #endif
